;; Generated package description from preview-auto.el  -*- no-byte-compile: t -*-
(define-package "preview-auto" "0.3.0.20241018.120408" "Automatic previews in AUCTeX" '((emacs "29.3") (auctex "14.0.5")) :commit "73874fe2c3c0d125f1395b9d8c1799c357444295" :authors '(("Paul D. Nelson" . "nelson.paul.david@gmail.com")) :maintainer '("Paul D. Nelson" . "nelson.paul.david@gmail.com") :keywords '("tex" "convenience") :url "https://github.com/ultronozm/preview-auto.el")
